==> mutual_credit-5.0.5.tar.gz: mutual_credit/src/Plugin/Condition/TransactionType.php <==
<?php

namespace Drupal\mcapi\Plugin\Condition;

use Drupal\rules\Core\RulesConditionBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\mcapi\Mcapi;
use Drupal\mcapi\Entity\Type;

/**
 * Provides a 'Transaction is of type' condition.
 *
 * @Condition(
 *   id = "mcapi_transaction_type",
 *   label = @Translation("Transaction is of type"),
 *   category = @Translation("Community Accounting"),
 *   provider = "rules",
 *   context_definitions = {
 *     "transaction" = @ContextDefinition("entity:mcapi_transaction",
 *       label = @Translation("Transaction"),
 *     ),
 *     "types" = @ContextDefinition("entity:mcapi_type",
 *       label = @Translation("Types"),
 *       description = @Translation("Check for the allowed transaction types"),
 *       multiple = TRUE
 *     )
 *   }
 * )
 */
class TransactionType extends RulesConditionBase {

  /**
   * {@inheritdoc}
   */
  public function summary() {
    // Hopefully the type names are translated.
    return $this->t(
      'Transaction type is @types',
      ['@types' => implode(', ', $this->configuration['types'])]
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'types' => [],
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['types'] = [
      '#title' => $this->t('Transaction types'),
      '#type' => 'checkboxes',
      '#options' => Mcapi::entityOptionsList(Type::loadMultiple()),
      '#default_value' => $this->configuration['types'],
      '#multiple' => TRUE,
    ];
    return parent::buildConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function doEvaluate($transaction, $types) {
    return in_array($transaction->type->target_id, $types);
  }

}

==> mutual_credit-5.0.8.tar.gz: mutual_credit/src/Plugin/Condition/TransactionType.php <==
<?php

namespace Drupal\mcapi\Plugin\Condition;

use Drupal\rules\Core\RulesConditionBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\mcapi\Mcapi;
use Drupal\mcapi\Entity\Type;

/**
 * Provides a 'Transaction is of type' condition.
 *
 * @Condition(
 *   id = "mcapi_transaction_type",
 *   label = @Translation("Transaction is of type"),
 *   category = @Translation("Community Accounting"),
 *   provider = "rules",
 *   context_definitions = {
 *     "transaction" = @ContextDefinition("entity:mcapi_transaction",
 *       label = @Translation("Transaction"),
 *       description = @Translation("Specifies the transaction for which to evaluate the condition."),
 *       assignment_restriction = "selector"
 *     ),
 *     "types" = @ContextDefinition("string",
 *       label = @Translation("Transaction type"),
 *       description = @Translation("The transaction type(s) to check for."),
 *       multiple = TRUE
 *     )
 *   }
 * )
 */
class TransactionType extends RulesConditionBase {

  /**
   * {@inheritdoc}
   */
  public function summary() {
    // Hopefully the type names are translated.
    return $this->t(
      'Transaction type is @types',
      ['@types' => implode(', ', $this->configuration['types'])]
    );
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'types' => [],
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['types'] = [
      '#title' => $this->t('Transaction types'),
      '#type' => 'checkboxes',
      '#options' => Mcapi::entityOptionsList(Type::loadMultiple()),
      '#default_value' => $this->configuration['types'],
      '#multiple' => TRUE,
    ];
    return parent::buildConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function doEvaluate($transaction, $types) {
    return in_array($transaction->type->target_id, $types);
  }

}
